\name{do.anova}
\alias{do.anova}
\title{Interface to yasmas bfaov function (generate ANOVA object)}
\description{Generate the YASMA ANOVA object that is further used to print
  ANOVA tables, calculate and print variance components and to
  calculate and print rank tests.
}
\usage{do.anova(model.info, array.data)}
\arguments{
  \item{model.info}{Standard model equations and additional information
    to generate the ANOVA object.}
  \item{array.data}{Array representation of a balanced design obtained
    by YASMA's rg2log.array or rg2array functions (See yasma help for
    additional information).}
}
\value{
  The function returns a bfaov object (See YASMA for details).
}
\examples{
\dontrun{
## read definition file
info <- read.defs('deffile.def')
## extract model.info from the info structure
model.info <- info.2.yasmaeqns(info)
## read data
RG <- tabdel2rg(info)
## and normalize it
RG <- do.normalize(RG, info)
## convert to array structure
aov.a <- rg2log.array(RG, log.ratio=T)
## and call do.anova
av <- do.anova(model.info, aov.a)
}
}
\seealso{
  \code{\link{tabdel2rg}}\code{\link{do.normalize}},
  \code{\link{aov.tab.varcomp.2.file}}
  and \code{\link{contrast.rank.2.file}}
}
\keyword{multivariate}
\keyword{models}
