\name{fspma.aovrnk}
\alias{fspma.aovrnk}
\title{ANOVA based ranking of time courses (or other multi-level effects)}
\description{ANOVA based ranking of experiments with respect to
  multi-level effects like time courses.}
\usage{fspma.aovrnk(info, model.info, array.data, fname=NULL, n.comps)}
\arguments{
  \item{model.info}{fspma's model.info structure.}
  \item{info}{fspma's info structure.}
  \item{array.data}{Array representation of a balanced design obtained
    by YASMA's rg2log.array or rg2array functions (See yasma help for
    additional information).}
  \item{fname}{Optional output file name, default taken from info
    structure (info\$ctrfname which resembles the 'Contrast.Outfile:'
    entry in the definition file). To guarantee unique file names this
    name is augmented with the string "anova." at the beginning.}
  \item{n.comps}{Number of comparisons to adjust for (this is calculated
    for the entire definition file).}
}
\value{
  fspma.aovrnk provides a ranking by means of single gene ANOVA
  models. The rank table is written as tab delimited file and returned
  to the calling function. Note that this object is not meant to be
  manipulated at user level.
}
\details{
  The ranking is based on the p-value of an ANOVA model calculated for
  each gene. The null hypothesis is that all levels in the rank effect
  have the same mean. Calculations are based on YASMA's bfaov object
  that is internally used to calculate the p-values of mixed models.
  Information about random effects etc. is treated
  apropriately. The function generates a tab delimited file that
  contains the gene information, the p-value of the F-test and the
  sample averages of all levels of the rank effect.
}
\examples{
\dontrun{
## read definition file
info <- read.defs('deffile.def')
## extract model.info from the info structure
model.info <- info.2.yasmaeqns(info)
## read data
RG <- tabdel2rg(info)
## and normalize it
RG <- do.normalize(RG, info)
## convert to array structure
aov.a <- rg2log.array(RG, log.ratio=T)
## and call do.anova
av <- do.anova(model.info, aov.a)
## calculate and write ANOVA rank tables (one ANOVA per gene).
fspma.aovrnk(info, model.info, array.data, n.comps=[plug in here])
}
}
\seealso{
  \code{\link{tabdel2rg}}, \code{\link{do.normalize}}, \code{\link{do.anova}},
  \code{\link{aov.tab.varcomp.2.file}} and \code{\link{contrast.rank.2.file}}
}
\keyword{IO}
\keyword{print}
