\name{fspma.wrapper}
\alias{fspma.wrapper}
\title{Friendly Statistics Package for Microarray Analysis (fspma) or
  Stats' without tears (i.e. coding)}
\description{Microarray data analysis with normalisation, bad quality expression
  treatment, ANOVA analysis and within ANOVA tests controlled by
  definition files.
}
\usage{fspma.wrapper(def.fname=NULL, RG=NULL, info=NULL,
na.debug.fname='na_debug.tsv', log.fname=fspma.logfile, init.logfile=T)}
\arguments{
  \item{def.fname}{File name of a definition file that controls analysis.}
  \item{RG}{An optional (extended) YASMA RG object that, if provided, will skip the
    data loading step and increase the efficiency of multiple rankings
    of the same data (e.g. using different normalisation methods).
    This RG object is an extension of yasma's RG structures and so far
    kept downward compatible. Some functions of yasma which
    modify RG (like normalization) tend to remove parts they do not
    know about. Calling such code will lead to incompatibilities of
    the resulting RG object with some functions within this library
    (e.g spike based normalization)! This can be resolved by using the
    RG adaptors provided by the library (\code{\link{fspmaRG.2.RG}}).}
  \item{info}{AN optional info structure otherwise read from definition file. This allows
    together with the Load.Only: entry in the definition file to include other
    processing steps on a scripting level and to repeat processing.}
  \item{na.debug.fname}{An optional parameter that is used to write debug
    information if NA values are read from the file (i.e. before the
    flaged spots are treated).}
  \item{log.fname}{Name of an ASCII log file used to store information
    about analysis steps. The name defaults to "fspma.log.txt". Use the
    log file to resolve problems with definition files.}
  \item{init.logfile}{Optional boolean flag that controls whether a
    definition file should be newly initialised. Defaulst to TRUE.}
}
\value{
  fspma.wrapper returns a fspma object. The object summarises all
  information that resulted from the analysis run. In particular we
  have:
  
  fspma.obj\$RG - an extended RG structure
  
  fspma.obj\$info - R representation of the definition file
  
  fspma.obj\$model.info - all model equations (spike normalisation,
  ANOVA model and models required for ranking and p-value calculation.
  
  fspma.obj\$aov.a and fspma.obj\$av - YASMA anova objects for debuging
  purpouse.
  
  fspma.obj\$plt.tabs - all rank tables useful for visualisation
  purpouse.
  
  If the "load only" flag (info\$load.only which corresponds to the
  Load.Only: entry) was set in the definition file, fspma.obj
  contains only the first two elements.
}
\details{
  fspma.wrapper is an efficient interface to microarray analysis with
  the YASMA package that comes with several generalizations to allow
  data conversion, normalization, ANOVA and test based inference for
  rather general microarray experiments. The function is controlled via
  a definition file that is adaptable to
  every balanced reference design and slide data. It covers two colour arrays
  with and without background signals and one colour data like affymetrix and
  meta data generated thereof, that was normalized or pre-processed
  elsewhere. The main restriction of this script is that it requires all
  slide-files of one experiment to use coherent column names in all
  files. If your experiment violates this rather modest requirement,
  then you need to process your files prior to using fspma.
  Details about definition files are provided in \code{\link{deffile.def}} for a
  time course with technical replicates and on slide replication.
  Some working examples are provided with the documentation as well.
  Finally we also povide a definition file with download instructions on
  how to obtain the accompanying arrays of a publicly available Affymetrix dataset
  at \url{http://www.ccbi.cam.ac.uk/software/psyk/software.html#fspma}.
  
  For further information on info see
  \code{\link{read.defs}}, for information on model.info see
  \code{\link{gen.yasma.eqns}}. RG, aov.a and av are
  yasma's RG structure, yasma's array data and yasma's ANOVA object and
  described in more detail in the help to the yasma package.
}
\examples{
\dontrun{
 ## FSPMA's logic is in the definition file. Analysis starting with
 ## data loading, normalisation, bad quality flag treatment, ANOVA
 ## calculations and rank tables are obtained in one go.
 ret <- fspma.wrapper('mouse_testis.def')
 ## And later, as soon as you have more understanding of what's going
 ## on inside, you get more flexibility with a def file that
 ## sets Load.Only T
 ret <- fspma.wrapper('mouse_load_only.def')
 RG <- fspmaRG.2.RG(ret)
 ## now use yasma functions on RG ( e.g. here we plot correlation
 ## over quantile of removed data)
 rg.rsq.plot(RG)
 ## and reduce the dataset manually (remove 0.1 quantile of least
 ## correlated genes,  which was found to be a sensible number by the
 ## previous plot) 
 RG <- rg.remove.quantile(RG, 0.1)
 ## now back to FSPMA data:
 ret.new <- RG.2.fspmaRG(RG, ret)
 ## before we continue with the fspma.wrapper (this call uses the
 ## modified experiment with fewer genes)
 ## anything from files)
 result <- fspma.wrapper(RG=RG, info=ret$info)
}
}
\seealso{
  \code{\link{tabdel2rg}}, \code{\link{do.normalize}},
  \code{\link{spike.normalize}}, \code{\link{do.anova}},
  \code{\link{fspmaRG.2.RG}},
  \code{\link{aov.tab.varcomp.2.file}},
  \code{\link{contrast.rank.2.file}},
  \code{\link{fspma.rankplot}} and \code{\link{fspma.avchannel}}
}
\keyword{IO}
\keyword{multivariate}
\keyword{datagen}
