\name{fspma2vsnarray}
\alias{fspma2vsnarray}
\alias{vsnarray2fspma}
\title{Conversion of FSPMA objects to and from vsn array}
\description{
  These functions act as adaptors from FSPMA objects to vsn array
  objects. They are meant to be used in cases where FSPMA array data
  should be normalised with vsn and converted to the variance
  stabilised representation used by vsn. IMPORTANT: the FSPMA def file
  must have turned off normalisation (Normalization:	NA), conversion
  to log set false (DoRG2logarray:	F) and processing stopped after
  data loading (Load.Only:	T).
}
\usage{fspma2vsnarray(fspma.obj)
vsnarray2fspma(fspma.obj, vsnarray)
}
\arguments{
  \item{fspma.obj}{is a FSPMA object as generated by fspma.wrapper.}
  \item{vsnarray}{is a vsn compatible array object with each column
    specifying an entire microarray.}
}
\value{
\code{fspma2vsnarray} takes a FSPMA object and returns a vsn array that
can undergo vsn transformation and normalisation.
\code{vsnarray2fspma} takes a FSPMA object and a vsn array and alters
the R and the G channel values in the FSPMA object. The modified FSPMA
object is returned.
}
\examples{
\dontrun{
library(fspma)
library(vsn)
fspma.obj <- fspma.wrapper('loadonly_nonorm_nolog.def')
## extract a vsn array object
vsnarray <- fspma2vsnarray(fspma.obj)
## use vsn transform and apply normalisation
vsnfit<-vsnMatrix(vsnarray,lts.quantile=0.51);
vsnarray<-predict(vsnfit, newdata=vsnarray);
## get the normalised data back into the fspma object
fspma.obj <- vsnarray2fspma(fspma.obj, vsnarray)
## and continue analysis in fspma wrapper
fspma.obj <- fspma.wrapper(RG=fspma.obj$RG, info=fspma.obj$info)
}
}
\seealso{
  \code{\link{tabdel2rg}} and \code{\link{fspma.wrapper}}
}
\keyword{IO}
