\name{gen.yasma.eqns}
\alias{gen.yasma.eqns}
\alias{info.2.yasmaeqns}
\title{Convert fspma info structure to model equations and additional
  modelling information.
}
\description{The functions info.2.yasmaeqns and gen.yasma.eqns are used
  to generate a standard set of model equations of ANOVA models that
  allow to get ANOVA tables, variance components and rank statistics.
}
\usage{
info.2.yasmaeqns(info)
gen.yasma.eqns(terms, randeffs, rank.term=1)
}
\arguments{
  \item{info}{Data structure obtained from function
    \code{\link{read.defs}}.
  }
  \item{terms}{Vector of effect names (model terms without gene effect).}
  \item{randeffs}{Boolean Vector of random effects flags.}
  \item{rank.term}{Index of the model term that defines the ranking we
    are interested in. This is typically an interaction term of the gene
    effect and the first effect in terms like a gene:time, a
    gene:species or a gene:type interaction and the default index will
    thus be 1.
  }
}
\value{Both functions return a model.info object that is not meant to be
  manipulated at user level.}
\details{
  Converts info to ANOVA equations and additional rank information
  necessary to apply YASMA to general experiments (like longitudinal 
  problems).
  gen.yasma.eqns generates default model equations (Regressors are 
  iterative nestings of effects) and additional information that we 
  need to calculate the ANOVA model and test statistics.
  The resulting model.info structure is used by functions
  \code{\link{do.anova}}, \code{\link{aov.tab.varcomp.2.file}} and 
  \code{\link{contrast.rank.2.file}}. The most important part of
  model.info is model.info\$eqn, this is the ANOVA model equation used
  for analysing the data.
}
\examples{
\dontrun{
info <- read.defs('deffile.def')
model.info <- info.2.yasmaeqna(info) ## calls gen.yasma.eqns
## alternatively:
terms <- c('time', 'sample')
rand. terms <- c(FALSE, TRUE)
model.info <- gen.yasma.eqns(terms, rand. terms)
}
}
\seealso{
  \code{\link{do.anova}}, \code{\link{aov.tab.varcomp.2.file}},
  \code{\link{contrast.rank.2.file}} and \code{\link{get.spk.nrm.eqn}}
}
\keyword{models}
\keyword{documentation}
