\name{tabdel2rg}
\alias{tabdel2rg}
\title{Loads the array data according to the specification in the
  definition file.}
\description{
  The function will load data from arbitrary tab delimited files, as
  long as the layout is identical. It can read double colour arrays with
  and without background information, single colour arrays and
  pre normalized meta data. See \code{\link{specify.experiments}} for
  detailed suggestions how to adapt the 
  definition file to various input scenarios. 
}
\usage{tabdel2rg(info, log.fname=fspma.logfile)}
\arguments{
  \item{info}{control structure as obtained by \code{\link{read.defs}}.}
  \item{log.fname}{name of logfile, defaults to fspma.logfile, which is
    'fsmpa.log.txt' unless reset by the user.}
}
\value{tabdel2rg reads microarray data from tab delimited files and
  returns an RG object. The information in RG is downwards compatible with YASMA's
  RG. It is however extended, to take bad quality markers and spikes into account.}
\details{
  Loading arrays is controlled by all column entries in the info
  structure (column names). The flag info\$load.fast, which contains the
  value of the "load.fast:" entry in the definition file allows to speed
  up data loading if and only if all files have the genes on the same
  positions. The list info\$dat.file.rd,
  which contains all entries of the "file.alloc:" description in the
  definition file allocates files to a corrsponding set of levels.
  Each entry of this allocation consists of a file name and its
  allocation. The final flag is a colour swap indicator.
  
  \code{R35_NIA1_AWX_ad_612_Fl_output.xls	1	1	F}
  specifies that this file represents data that corresponds to the
  first level in the first effect (here time) and to the first level in
  the second effect (here a technical replication). The last column
  specifies that this array is not a colour swap.
  
  The function first checks whether the column header information
  corresponds to the predefined setting in the definition file and then
  reads gene names and the array data (including a spotter flag that
  indicates invalid spotter results). After all data has been read, the
  function builds an RG structure.
}
\examples{
\dontrun{
## read definition file
info <- read.defs('deffile.def')
## read data
RG <- tabdel2rg(info)
}
}
\seealso{
  \code{\link{fspma.wrapper}}, \code{\link{read.defs}} and
  \code{\link{deffile.def}}.
}
\keyword{IO}
