\name{treat.na}
\alias{treat.na}
\alias{knn.impute}
\alias{del.impute}
\title{Treat flaged (missing) Spots and NA values}
\description{This set of functions is provided to resolve NA values in
  the RG structure that may arise because they were contained in the
  original data. NA is also set in case that the flag information for
  spots is loaded and a flag equals the info\$flag.nack entry (Flag.NOK:
  line in the definition file). The behaviour in the context of missing
  values can be controlled by the "Impute.Mthd:" entry in the defnition
  file. Options are knn<TAB>n, del or NA. The latter implies no action.
  After issuing a warning message, "no action" is however overridden
  by del, if NA's are found in the data. This user request was added,
  to avoid that processing terminates unsucessfully if NA's are left
  untreated.
}
\usage{
treat.na(RG, method, go2log=T)
knn.impute(RG, k=10, go2log=T)
del.impute(RG)
}
\arguments{
  \item{RG}{A YASMA RG object, who's NA entries will be modified by
    k nearest neighbour imputation or deleted.
  }
  \item{method}{A method string that is 'knn' for k nearest neighbour
    imputation (Troyanskaya et.al.), 'del' if NA entries are resolved
    by removing the corresponding genes and 'NA' if there is no action taken.
  }
  \item{go2log}{Optional flag, specifying whether data should be moved
    to log scale before imputing.
  }
  \item{k}{Number of neighbours used for calculating the knn imputation.
  }
}
\value{
  These functions return RG objects, with bad quality spots
  corrected or the corresponding genes removed.
}
\details{
  These functions provide possibilities to resolve missing spot issues
  or NA values in RG colour channels. The original proposal in yasma to
  use the ANOVA model for imputing fails to work due to the large memory
  requirements of the corresponding linear model.
}
\examples{
\dontrun{
## read the data
RG <- tabdel2rg(info)
## set the channel entries of missing or failed spots to NA:
if(!any(is.na(info$flag.nack)))
  {
    set.na.dx <- RG$Flg==info$flag.nack
    RG$R[set.na.dx] <- NA
    RG$G[set.na.dx] <- NA
  }
## now we treat NA according to info$impute.mthd
RG <- treat.na(RG, info$impute.mthd)
## alternatively we can do this by hand and call
RG <- knn.impute(RG, 20) ## using the 20 closest profiles to impute
## or remove the corresponding genes
RG <- del.impute(RG)
}
}
\seealso{
  \code{\link{tabdel2rg}}, \code{\link{deffile.def}},
  \code{\link{fspma.wrapper}}
}
\keyword{manip}
