sum.na <- function(a) {
  sum(a[!is.na(a)])
}

is.subset <- function(x,y) {
  all(is.element(x,y))
}  

is.subvector <- function(v,w) {
  all(v <= w)
}

vectorequal <- function(v,w) {
  all(v == w)
}

incr.vec <- function(v,u) {
  l <- length(v)
  i <- l
  while (i > 0 && v[i] == u[i])
    i <- i - 1
  if (i == 0)
    v <- c(0)
  else {
    v[i] <- v[i] + 1
    if (i < l) {
      k <- v[i] + 1
      for (j in (i+1):l) {
        v[j] <- k
        k <- k + 1
      }
    }
  }
  v
}

fixed.s.subsets <- function(n,d) {
  v <- 1:d
  u <- (n-d+1):n
  l <- list(v)
  while((v <- incr.vec(v,u))[1] != 0)
    l <- c(l,list(v))
  l
}

all.subsets <- function(n,d) {
  if (missing(d)) d <- n
  l <- list()
  for (i in 1:d)
    l <- c(l,fixed.s.subsets(n,i))
  l
}

# see Venables Ripley, S programming, p 49
#all.subsets <- function(n,r,v=1:n) {
#  if (r <= 0) NULL else
#  if (r >= n) v[1:n] else
#  rbind(cbind(v[1],all.subsets(n-1,r-1,v[-1])),
#      all.subsets(n-1,r,v[-1]) )
#}

all.vectors <- function(n,d) {
  if (missing(d))
    d <- n
  inters <- all.subsets(n,d)
  m <- NULL
  for (i in 1:length(inters)) {
    inds <- rep(0,n)
    inds[inters[[i]]] <- 1
    m <- cbind(m,inds)
  }
  colnames(m) <- NULL
  t(m)
  #l <- list(); for (i in 1:d) l <- c(l,list(0:1));
  #as.matrix(do.call("expand.grid",l))
}

print.txt.matrix <- function(m,digits=5,width=11,file="",
    lower.triangle=F) {
  cat("",file=file)
  facat <- function(...) cat(...,file=file,append=T)
  for (i in 1:ncol(m)) {
    facat(i)
    if (i < ncol(m)) facat("\t")
    else facat("\n")
  }
  for (i in 1:nrow(m)) {
    facat(i,"\t")
    for (j in 1:ncol(m)) {
      #if (j %% 5 == 0) facat("\n   ")
      if (lower.triangle && j > i) facat(" ")
      else facat(formatC(m[i,j],digits,width)," ")
      if (j < ncol(m)) facat("\t")
    }
    facat("\n")
  }
}

tex.matrix.intro <- "Include in latex header:\n\n\\usepackage{dcolumn}\n\\newcolumntype{.}{D{.}{.}{-1}}\n\n"
tex.matrix.preamble <- "\\begin{tabular}{"
tex.matrix.conclusion <- "\\end{tabular}\n\n"

print.tex.matrix <- function(m,digits=5,width=11,file="",
    tadjust=".",lower.triangle=F) {
  if (file == "") {
    cat(tex.matrix.intro)
    cat(tex.matrix.preamble)
  } else cat(tex.matrix.preamble,file=file)

  facat <- function(...) cat(...,file=file,append=T)
  facat(tadjust,"|",sep="")
  for (i in 1:ncol(m)) facat(tadjust)
  facat("}\n")
  facat(" & ")
  for (i in 1:ncol(m)) {
    facat(i)
    if (i < ncol(m)) facat(" & ")
    else facat(" \\\\")
  }
  facat("\n\\hline\n")
  for (i in 1:nrow(m)) {
    facat(i," & ")
    for (j in 1:ncol(m)) {
      if (j %% 5 == 0) facat("\n   ")
      if (lower.triangle && j > i) facat(" ")
      else facat(formatC(m[i,j],digits,width)," ")
      if (j < ncol(m)) facat(" & ")
    }
    if (i < nrow(m)) facat(" \\\\\n")
    else facat("\n")
  }
  facat(tex.matrix.conclusion)
}


