%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file was automatically generated by Rdoc on 2003-02-17 11:27:55.
% Do NOT modify this file, instead modify the source (bfanova.R).
% Rdoc is copyright (C) 2001, Henrik Bengtsson, henrikb@braju.com.
% Download the Rdoc compiler at http://www.braju.com/R/
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 \name{over.under}
 \alias{over.under}
 \alias{over.under.level}
 \title{Analysis of over- and under-expression from ANOVA}
 \description{
   Calculates p-values for over- and under-expression from ANOVA model.
   Bootstrapping from residuals can be used to get more
   reliable results than using residual error estimates.
   To calculate over- or under-expressed genes use
   \code{\link{data.over.under}} }
 \usage{
   over.under(anv,rounds=50,
       formula=NULL,gloe=NULL,a=NULL,drop.b=F,fast=T,
       stats.only=T,RG=NULL,normalize=T,span=0.4)
   over.under.level(anv,rml,formulas,
       levels.seq,rounds=50,
       gloe.l=NULL,a=NULL,drop.b=F,
       stats.only=T,RG=NULL,normalize=T,span=0.4)
 }
 \synopsis{over.under(anv,rounds=50, formula=NULL,gloe=NULL,a=NULL,drop.b=F,fast=T, stats.only=T,RG=NULL,normalize=T,span=0.4)}
 \arguments{
   \item{anv}{result of ANOVA analysis, see \code{\link{bfaov}}}
   \item{pvalue}{siginificance level}
   \item{rounds}{if nonzero, p-values are also determined by
     bootstrapping residuals with \code{rounds} resamplings}
   \item{formula}{a model formula, see \code{\link{bfaov}}}
   \item{formulas}{a list of a model formulas, describing
     the residuals for hierarchical bootstrap,
     see \code{\link{bfaov}}}
   \item{levels.seq}{a list of main effects, the levels for hierarchical
     bootstrap}
   \item{drop.b}{drop bootstrap results (which can become very large
     depending on \emph{rounds})}
   \item{rml}{\code{rml} data as return by \code{\link{reml.bfaov}}}
   \item{gloe}{a loess object from a smooth regression to the
     residuals (over estimates), for example, from an earlier call to
     \code{boots.vg}, see also
     \code{\link{loess}} }
   \item{gloe.l}{a list of loess objects as in \code{gloe} for hierarchical
     bootstrap}
   \item{fast}{if set to T, the compiled bootstrap is called which is
     \emph{much} faster then the R version, but might not be
     available on every platform }
   \item{a}{a balanced factorial data array, see
     \code{\link{rg2log.array}} }
   \item{RG}{RG microarray data structure, see \code{\link{read.rg}}}
   \item{normalize}{}
   \item{span}{span for loess smoother}
   \item{stats.only}{if TRUE, only mean and standard deviation of
     VG or G effect is collected for each bootstrap replicate}
 }
 \details{
   \code{over.under.level} performs a hierarchical bootstrap as
   specified in \code{formulas} and \code{levels.seq}.
   See \code{\link{sd.vg}} for details on p-values for significant
   differential expression. Bootstrapping residuals can be used to
   get more reliable p-values
 }
 \value{
   List containing:
   \item{p.over, p.under}{p-values of over-, under-expressed genes}
   \item{p.over.b, p.under.b}{p-values of over-, under-expressed genes
     from bootstrap }
   \item{rounds}{the input parameter}
   \item{b}{a matrix containing the bootstrap results as columns}
   \item{gloe}{a loess object from a smooth regression to the
     residuals for the bootstrap}
   \item{gloe.l}{a list of loess objects as in \code{gloe} for hierarchical
     bootstrap}
   \item{anv}{the input bfaov object}
   \item{RG}{the input RG object}
 }
 \examples{
   data(trcs)
   ou <- over.under(trcs.av,rounds=0)
   ou$p.over

   RG <- rg.remove.quantile(trcs.RG,0.1)
   RG <- rg.scale.normalize(RG)
   a <- rg2log.array(RG,log.ratio=T)
   av <- bfaov(~G + S/A + G:S + G:S:A,a)

   rml <- reml.bfaov(av,c("S","A"),anova.only=T)
   print.reml(rml)

   formulas <- list(~G + S + A,
       ~G + S + A + G:S,~G + S + A + G:S + G:S:A)
   levels.seq <- c("S","A")
   ou.b <- over.under.level(av,rml,rounds=500,
       formulas=formulas,levels.seq=levels.seq,
       RG=RG,span=0.4,stats.only=F)

   # normality of coefficients obtained by bootstrap:
   x <- ou.b$b[50,]; qqnorm(x); qqline(x);
   ks.test(x,"pnorm",mean(x),sd(x)); shapiro.test(x)

   # plot loess fit for residuals:
   opar <- par(mfrow=c(3,1))
   for (i in 1:3) plot.loess(ou.b$gloe.l[[i]])
   par(opar)
 }
 \seealso{
   \code{\link{data.over.under}}
 }
 \keyword{models}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% End of File
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
