%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file was automatically generated by Rdoc on 2003-02-17 11:27:55.
% Do NOT modify this file, instead modify the source (bfanova.R).
% Rdoc is copyright (C) 2001, Henrik Bengtsson, henrikb@braju.com.
% Download the Rdoc compiler at http://www.braju.com/R/
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 \name{reml.bfaov}
 \alias{reml.bfaov}
 \alias{reml.kt}
 \alias{print.reml}
 \alias{optim.design}
 \title{REML estimates of variance components}
 \description{
   REML estimates for balanced factorial designs
 }
 \usage{
   reml.bfaov(anv,rand.facs,formula=NULL,zero=0.0001,anova.only=T)
   reml.kt(ms,df,sf,A,zero=0.0001,anova=T)
   print.reml(rml)
   optim.design(anv,coords,w,limit=NULL,design=NULL)
 }
 \arguments{
   \item{anv}{a bfaov object, see \code{\link{bfaov}}}
   \item{rand.facs}{vector of random factors}
   \item{formula}{a model formula, see \code{\link{bfaov}}}
   \item{zero}{limit for assuming a variance component is zero}
   \item{anova.only}{ANOVA estimates of variance components, can
     result in negative components, but is fast}
   \item{ms}{vector of mean squares}
   \item{df}{vector of degrees of freedom}
   \item{sf}{vector of coefficients of variance components in expected
     mean square}
   \item{A}{indicator matrix of variance components in expected
     mean square}
   \item{rml}{list returned by \code{reml.bfaov}}
   \item{coords}{list of random main effects}
   \item{w}{the cost vector for the random main effects}
   \item{limit}{a limit on the costs of an experimental design}
   \item{design}{vector describing hierarchical design: how
     many of the first effect, how many of the second effect
     nested in each of the first, etc.}
   \item{anova}{if TRUE, negative MS estimates for variance components
     are set to zero; otherwise, }
 }
 \value{
   \code{reml.bfaov} returns a list of
   \item{s.sq}{estimates of variance components}
   \item{MS}{pseudo mean squares yielding the the variance components}
   \item{error}{final error in the Kuhn-Tucker optimization}
   \item{grad}{the gradient of the Kuhn-Tucker condition}
   \item{coords}{list of symbols indicating the interaction effects}
 }
 \details{
   If effects are assumed to be random the resulting mixed model
   provides estimates of variance components instead of mean squares.
   For balanced factorial designs the restricted maximum likelihood
   estimates (REML) of the variance components can be calculated by
   solving an optimization problem involving the ANOVA mean squares
   (see W. A. Thompson, The problem of negative estimates of variance
   components, Ann. of math. statistics 33:273-289, 1962).
 }
 \examples{
   data(trcs)
   RG <- rg.remove.quantile(trcs.RG,0.1)
   RG <- rg.scale.normalize(RG)
   a <- rg2log.array(RG,log.ratio=T)
   av <- bfaov(~G + S/A + G:S + G:S:A,a)

   # assume random effects S and A:
   rml <- reml.bfaov(av,c("S","A"),~G + S/A + G:S + G:S:A)
   print.reml(rml)
   optim.design(av,c("S","A","Q"),c(50,10,1),limit=200)
   
   # W.A. Thompson example (Technometrics 5:441-449, 1963, p448)
   
   df <- c(3,1,3,8)
   sf <- c(4,8,2,1)
   ms <- c(5,8,9,4)
   A <- rbind(c(1,0,1,1),c(0,1,1,1),c(0,0,1,1),c(0,0,0,1))
   reml.kt(ms,df,sf,A,zero=0.01,anova=F)
 }
 \seealso{
   \code{\link{bfaov}}
 }
 \keyword{models}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% End of File
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
